//-----------------------------------------------------------------------------
// Copyright  1999 - Philip Howard
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//-----------------------------------------------------------------------------
// package	rmd160
// version	1.2.0
// homepage	http://phil.ipal.org/freeware/rmd160/
//-----------------------------------------------------------------------------
// author	Philip Howard
// email	phil@ipal.org
// homepage	http://phil.ipal.org/
//-----------------------------------------------------------------------------

#include "rmd160_lib.h"

#include <stdio.h>

//-----------------------------------------------------------------------------
// function	rmd160_append_file
//
// purpose	Append the contents of an open FILE to the RMD160
//		checksum.
//
// arguments	1 (RMD160) reference handle to RMD160 instance.
//		2 (FILE *) pointer to open file object.
//
// returns	(int) RMD160_OK
//		(int) RMD160_ERR_INVALID_ARG
//		(int) RMD160_ERR_READ
//
// note		If the calling program reads any data from the file
//		pointer that needs to be included in the checksum, then
//		it must append them with rmd160_append() before
//		calling rmd160_append_fd().
//-----------------------------------------------------------------------------

#define FUNCTION_NAME "rmd160_append_file"

int
rmd160_append_file (
	RMD160		arg_obj
,
	FILE *		arg_file
)
{
    size_t		nread				;
    unsigned char	buffer	[ RMD160_BUFSIZ ]	;

    if ( ! arg_file ) return RMD160_ERR_INVALID_ARG;
    if ( ! arg_obj ) return RMD160_ERR_INVALID_ARG;

    for (;;) {
	nread = fread( buffer , 1 , RMD160_BUFSIZ , arg_file );
	if ( nread < 1 ) {
	    return RMD160_ERR_READ;
	}
	rmd160_append( arg_obj , nread , buffer );
    }

    return RMD160_OK;
}

#undef FUNCTION_NAME
