//-----------------------------------------------------------------------------
// Copyright  1999 - Philip Howard
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//-----------------------------------------------------------------------------
// package	rmd160
// version	1.2.0
// homepage	http://phil.ipal.org/freeware/rmd160/
//-----------------------------------------------------------------------------
// author	Philip Howard
// email	phil@ipal.org
// homepage	http://phil.ipal.org/
//-----------------------------------------------------------------------------

#include "rmd160_lib.h"

//-----------------------------------------------------------------------------
// function	rmd160_sum_bytes
//
// purpose	Get the resultant checksum of the RMD160 object as
//		an array of 20 8-bit bytes.
//
// arguments	(RMD160) reference handle to RMD160 instance.
//		(unsigned char *) pointer to 20 bytes of 8 bits where
//				the checksum result is to be stored.
//
// returns	(unsigned char *) pointer to returned result
//		(unsigned char *) NULL if error
//-----------------------------------------------------------------------------

#define FUNCTION_NAME "rmd160_sum_bytes"

unsigned char *
rmd160_sum_bytes (
	RMD160			arg_handle
,
	unsigned char *		arg_result_p
)
{
    rmd160uint32	temp	[5]	;

    rmd160uint32 *	ptemp		;

    unsigned char *	result_p	;


    //-- Make sure we have a result buffer.
    if ( ! ( result_p = arg_result_p ) ) {
	if ( ! ( result_p = malloc( 20 ) ) ) return NULL;
    }

    //-- Get the results as words.
    if ( ! rmd160_sum_words( arg_handle , temp ) ) {
	if ( ! arg_result_p ) free( result_p );
	return NULL;
    }

    //-- Convert words to bytes in the result buffer.
    ptemp = temp;
    {
	int i;
	for ( i = 0 ; i < 5 ; ++ i ) {
	    register rmd160uint32 w;
	    * ( arg_result_p ++ ) = 0xff & ( w = * ptemp );
	    * ( arg_result_p ++ ) = 0xff & ( w >>  8 );
	    * ( arg_result_p ++ ) = 0xff & ( w >> 16 );
	    * ( arg_result_p ++ ) = 0xff & ( w >> 24 );
	    ++ ptemp;
	}
    }

    //-- All done, return.
    return arg_result_p;

}

#undef FUNCTION_NAME
